MediaData class

Implementers

Constructors

MediaData({required String? albumId, required String assetId, required String? uri, required MediaType type, required Uint8List? imageData})

Properties

albumId → String?
final
assetId → String
final
hashCode → int
The hash code for this object.
no setterinherited
imageData → Uint8List?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MediaType
final
uri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map json) → MediaData